@@ -3,8 +3,7 @@
 
 
 class SignalsError(Exception):
-    """ Exception raised when a signal connection (binding) fails.
-    """
+    """Exception raised when a signal connection (binding) fails."""
 
     def __init__(self, message):
         self.message = message
