@@ -9,7 +9,7 @@ from signals_utils.signals.mongo import decorator
 
 
 class TestConnectorConnect(TestCase):
-    @patch.object(signals.post_save, 'connect')
+    @patch.object(signals.post_save, "connect")
     def test_connect_raises_signals_error_if_bad_connection(self, mock_connect):
         # Arrange
         mock_connect.side_effect = Exception()
@@ -18,7 +18,7 @@ class TestConnectorConnect(TestCase):
         with self.assertRaises(exceptions.SignalsError):
             connector.connect(object, signals.post_save, self)
 
-    @patch.object(signals.post_save, 'connect')
+    @patch.object(signals.post_save, "connect")
     def test_decorator_raises_signals_error_if_bad_connection(self, mock_connect):
         # Arrange
         mock_connect.side_effect = Exception()
